<?php
/**
 * @package     KShield.Plugin
 * @subpackage  SSO.KShield
 * 
 * @author      TDP Ltd. <tdp@tdp.cz>
 * @copyright   Copyright (C) 2011 TDP Ltd. All rights reserved. 
 * @license     GNU General Public License version 2 or later; see LICENSE.txt
 * 
 * --- Original based on JAuthTools ---
 * @url         http://joomlacode.org/gf/project/jauthtools
 * @author      Sam Moffatt <sam.moffatt@toowoombarc.qld.gov.au>
 * @author      Toowoomba Regional Council Information Management Department
 * @copyright   (C) 2008 Toowoomba Regional Council/Sam Moffatt 
 * ------------------------------------
 */

defined('_JEXEC') or die;

jimport('joomla.plugin.plugin');

/**
 * Attempts to match a user based on the supplied server variables.
 * 
 * @package     KShield.Plugin
 * @subpackage  SSO.KShield
 */
class plgSSOKShield extends JPlugin 
{
	/**
	 * This method checks if there is a remote user for given IP
	 * 
	 * @return  string  Username of detected user
	 * @since   1.0
	 */
	public function detectRemoteUser() 
	{	
		$ssoUrl = $this->params->get('kshieldURL','http://127.0.0.1:8485');
		$apiKey = $this->params->get('apiKey','');
		$userAttr = $this->params->get('usernameAttribute','');
		
		$remote_user = $this->getUsernameByIP($ssoUrl, $this->getClientIP(), $apiKey, $userAttr);
		
		if(is_null($remote_user) || $remote_user=='') return null;
				
		return strtolower($remote_user);
	}
	
	function getClientIP() {
		return $_SERVER["REMOTE_ADDR"] ;
	}

	function getUsernameByIP($ssoUrl, $ip, $apiKey, $userAttr) 
	{
		$ssoParams = "";
		if(!is_null($apiKey) && $apiKey!='') {
			$ssoParams = "?key=".$apiKey;
		}
		if(!is_null($userAttr) && $userAttr!='') {
			if($ssoParams!='') {
			  $ssoParams = $ssoParams."&";
			}
			else {
			  $ssoParams = "?";
			}
			$ssoParams = $ssoParams."attributes=".$userAttr;
		}
		
		$json_url = $ssoUrl.'/json/userByIP/'.$ip.$ssoParams;
		$ch = curl_init( $json_url );
		
		$options = array(
			CURLOPT_RETURNTRANSFER => true
			);
		
		curl_setopt_array( $ch, $options );
		
		$result =  curl_exec($ch);
		
		if ($result) {
			$obj = json_decode($result,true);
			
			if(!is_null($userAttr) && $userAttr!='') {
				if ($obj["attributes"]) {
					$attrs = $obj["attributes"];
					if ($attrs[$userAttr]) {
						return $attrs[$userAttr];
					}
				}
			}
			else {
				if ($obj["screenName"]) {
					return $obj["screenName"];
				}
			}
		}
		return null;
	}
}
